# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ReceiverResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'serial_number': 'str',
        'firmware_version': 'str',
        'network_id': 'str',
        'receiver_location_type': 'ReceiverLocationTypeCodes',
        'receiver_type': 'ReceiverTypeCodes',
        'rf_channel': 'int',
        'pending_rf_channel': 'int',
        'mac_address': 'str',
        'radio_mac_address': 'str',
        'location': 'LocationChild',
        'corporation': 'CorporationChild',
        'name': 'str',
        'last_base_station': 'BaseStationChild',
        'last_status_update': 'datetime'
    }

    attribute_map = {
        'id': 'Id',
        'serial_number': 'SerialNumber',
        'firmware_version': 'FirmwareVersion',
        'network_id': 'NetworkId',
        'receiver_location_type': 'ReceiverLocationType',
        'receiver_type': 'ReceiverType',
        'rf_channel': 'RfChannel',
        'pending_rf_channel': 'PendingRfChannel',
        'mac_address': 'MacAddress',
        'radio_mac_address': 'RadioMacAddress',
        'location': 'Location',
        'corporation': 'Corporation',
        'name': 'Name',
        'last_base_station': 'LastBaseStation',
        'last_status_update': 'LastStatusUpdate'
    }

    def __init__(self, id=None, serial_number=None, firmware_version=None, network_id=None, receiver_location_type=None, receiver_type=None, rf_channel=None, pending_rf_channel=None, mac_address=None, radio_mac_address=None, location=None, corporation=None, name=None, last_base_station=None, last_status_update=None):  # noqa: E501
        """ReceiverResponse - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._serial_number = None
        self._firmware_version = None
        self._network_id = None
        self._receiver_location_type = None
        self._receiver_type = None
        self._rf_channel = None
        self._pending_rf_channel = None
        self._mac_address = None
        self._radio_mac_address = None
        self._location = None
        self._corporation = None
        self._name = None
        self._last_base_station = None
        self._last_status_update = None
        self.discriminator = None
        self.id = id
        self.serial_number = serial_number
        if firmware_version is not None:
            self.firmware_version = firmware_version
        if network_id is not None:
            self.network_id = network_id
        self.receiver_location_type = receiver_location_type
        self.receiver_type = receiver_type
        if rf_channel is not None:
            self.rf_channel = rf_channel
        if pending_rf_channel is not None:
            self.pending_rf_channel = pending_rf_channel
        if mac_address is not None:
            self.mac_address = mac_address
        if radio_mac_address is not None:
            self.radio_mac_address = radio_mac_address
        if location is not None:
            self.location = location
        if corporation is not None:
            self.corporation = corporation
        if name is not None:
            self.name = name
        if last_base_station is not None:
            self.last_base_station = last_base_station
        if last_status_update is not None:
            self.last_status_update = last_status_update

    @property
    def id(self):
        """Gets the id of this ReceiverResponse.  # noqa: E501


        :return: The id of this ReceiverResponse.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ReceiverResponse.


        :param id: The id of this ReceiverResponse.  # noqa: E501
        :type: int
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def serial_number(self):
        """Gets the serial_number of this ReceiverResponse.  # noqa: E501


        :return: The serial_number of this ReceiverResponse.  # noqa: E501
        :rtype: str
        """
        return self._serial_number

    @serial_number.setter
    def serial_number(self, serial_number):
        """Sets the serial_number of this ReceiverResponse.


        :param serial_number: The serial_number of this ReceiverResponse.  # noqa: E501
        :type: str
        """
        if serial_number is None:
            raise ValueError("Invalid value for `serial_number`, must not be `None`")  # noqa: E501

        self._serial_number = serial_number

    @property
    def firmware_version(self):
        """Gets the firmware_version of this ReceiverResponse.  # noqa: E501


        :return: The firmware_version of this ReceiverResponse.  # noqa: E501
        :rtype: str
        """
        return self._firmware_version

    @firmware_version.setter
    def firmware_version(self, firmware_version):
        """Sets the firmware_version of this ReceiverResponse.


        :param firmware_version: The firmware_version of this ReceiverResponse.  # noqa: E501
        :type: str
        """

        self._firmware_version = firmware_version

    @property
    def network_id(self):
        """Gets the network_id of this ReceiverResponse.  # noqa: E501


        :return: The network_id of this ReceiverResponse.  # noqa: E501
        :rtype: str
        """
        return self._network_id

    @network_id.setter
    def network_id(self, network_id):
        """Sets the network_id of this ReceiverResponse.


        :param network_id: The network_id of this ReceiverResponse.  # noqa: E501
        :type: str
        """

        self._network_id = network_id

    @property
    def receiver_location_type(self):
        """Gets the receiver_location_type of this ReceiverResponse.  # noqa: E501


        :return: The receiver_location_type of this ReceiverResponse.  # noqa: E501
        :rtype: ReceiverLocationTypeCodes
        """
        return self._receiver_location_type

    @receiver_location_type.setter
    def receiver_location_type(self, receiver_location_type):
        """Sets the receiver_location_type of this ReceiverResponse.


        :param receiver_location_type: The receiver_location_type of this ReceiverResponse.  # noqa: E501
        :type: ReceiverLocationTypeCodes
        """
        if receiver_location_type is None:
            raise ValueError("Invalid value for `receiver_location_type`, must not be `None`")  # noqa: E501

        self._receiver_location_type = receiver_location_type

    @property
    def receiver_type(self):
        """Gets the receiver_type of this ReceiverResponse.  # noqa: E501


        :return: The receiver_type of this ReceiverResponse.  # noqa: E501
        :rtype: ReceiverTypeCodes
        """
        return self._receiver_type

    @receiver_type.setter
    def receiver_type(self, receiver_type):
        """Sets the receiver_type of this ReceiverResponse.


        :param receiver_type: The receiver_type of this ReceiverResponse.  # noqa: E501
        :type: ReceiverTypeCodes
        """
        if receiver_type is None:
            raise ValueError("Invalid value for `receiver_type`, must not be `None`")  # noqa: E501

        self._receiver_type = receiver_type

    @property
    def rf_channel(self):
        """Gets the rf_channel of this ReceiverResponse.  # noqa: E501


        :return: The rf_channel of this ReceiverResponse.  # noqa: E501
        :rtype: int
        """
        return self._rf_channel

    @rf_channel.setter
    def rf_channel(self, rf_channel):
        """Sets the rf_channel of this ReceiverResponse.


        :param rf_channel: The rf_channel of this ReceiverResponse.  # noqa: E501
        :type: int
        """

        self._rf_channel = rf_channel

    @property
    def pending_rf_channel(self):
        """Gets the pending_rf_channel of this ReceiverResponse.  # noqa: E501


        :return: The pending_rf_channel of this ReceiverResponse.  # noqa: E501
        :rtype: int
        """
        return self._pending_rf_channel

    @pending_rf_channel.setter
    def pending_rf_channel(self, pending_rf_channel):
        """Sets the pending_rf_channel of this ReceiverResponse.


        :param pending_rf_channel: The pending_rf_channel of this ReceiverResponse.  # noqa: E501
        :type: int
        """

        self._pending_rf_channel = pending_rf_channel

    @property
    def mac_address(self):
        """Gets the mac_address of this ReceiverResponse.  # noqa: E501


        :return: The mac_address of this ReceiverResponse.  # noqa: E501
        :rtype: str
        """
        return self._mac_address

    @mac_address.setter
    def mac_address(self, mac_address):
        """Sets the mac_address of this ReceiverResponse.


        :param mac_address: The mac_address of this ReceiverResponse.  # noqa: E501
        :type: str
        """

        self._mac_address = mac_address

    @property
    def radio_mac_address(self):
        """Gets the radio_mac_address of this ReceiverResponse.  # noqa: E501


        :return: The radio_mac_address of this ReceiverResponse.  # noqa: E501
        :rtype: str
        """
        return self._radio_mac_address

    @radio_mac_address.setter
    def radio_mac_address(self, radio_mac_address):
        """Sets the radio_mac_address of this ReceiverResponse.


        :param radio_mac_address: The radio_mac_address of this ReceiverResponse.  # noqa: E501
        :type: str
        """

        self._radio_mac_address = radio_mac_address

    @property
    def location(self):
        """Gets the location of this ReceiverResponse.  # noqa: E501


        :return: The location of this ReceiverResponse.  # noqa: E501
        :rtype: LocationChild
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this ReceiverResponse.


        :param location: The location of this ReceiverResponse.  # noqa: E501
        :type: LocationChild
        """

        self._location = location

    @property
    def corporation(self):
        """Gets the corporation of this ReceiverResponse.  # noqa: E501


        :return: The corporation of this ReceiverResponse.  # noqa: E501
        :rtype: CorporationChild
        """
        return self._corporation

    @corporation.setter
    def corporation(self, corporation):
        """Sets the corporation of this ReceiverResponse.


        :param corporation: The corporation of this ReceiverResponse.  # noqa: E501
        :type: CorporationChild
        """

        self._corporation = corporation

    @property
    def name(self):
        """Gets the name of this ReceiverResponse.  # noqa: E501


        :return: The name of this ReceiverResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this ReceiverResponse.


        :param name: The name of this ReceiverResponse.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def last_base_station(self):
        """Gets the last_base_station of this ReceiverResponse.  # noqa: E501


        :return: The last_base_station of this ReceiverResponse.  # noqa: E501
        :rtype: BaseStationChild
        """
        return self._last_base_station

    @last_base_station.setter
    def last_base_station(self, last_base_station):
        """Sets the last_base_station of this ReceiverResponse.


        :param last_base_station: The last_base_station of this ReceiverResponse.  # noqa: E501
        :type: BaseStationChild
        """

        self._last_base_station = last_base_station

    @property
    def last_status_update(self):
        """Gets the last_status_update of this ReceiverResponse.  # noqa: E501


        :return: The last_status_update of this ReceiverResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._last_status_update

    @last_status_update.setter
    def last_status_update(self, last_status_update):
        """Sets the last_status_update of this ReceiverResponse.


        :param last_status_update: The last_status_update of this ReceiverResponse.  # noqa: E501
        :type: datetime
        """

        self._last_status_update = last_status_update

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ReceiverResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ReceiverResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.board_tickets_api import BoardTicketsApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestBoardTicketsApi(unittest.TestCase):
    """BoardTicketsApi unit test stubs"""

    def setUp(self):
        self.api = BoardTicketsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_ticket(self):
        """Test case for create_ticket

        Creates a new ticket  # noqa: E501
        """
        pass

    def test_delete_ticket(self):
        """Test case for delete_ticket

        Deletes a ticket  # noqa: E501
        """
        pass

    def test_get_ticket(self):
        """Test case for get_ticket

        Gets the specified ticket  # noqa: E501
        """
        pass

    def test_get_tickets(self):
        """Test case for get_tickets

        Gets tickets  # noqa: E501
        """
        pass

    def test_update_ticket(self):
        """Test case for update_ticket

        Updates an existing ticket  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class PictureFileMetadataResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'file_type': 'ContentType',
        'display_name': 'str',
        'parent_folder_id': 'str',
        'description': 'str',
        'location': 'LocationChild',
        'corporation': 'CorporationChild',
        'group_ids': 'list[str]',
        'id': 'str',
        'file_name': 'str',
        'thumbnail_file_name': 'str',
        'creation_date': 'datetime',
        'update_date': 'datetime',
        'file_count': 'int',
        'folder_count': 'int',
        'is_root_folder': 'bool',
        'tags': 'list[TagChild]',
        'image_height': 'int',
        'image_width': 'int',
        'is_primary_image': 'bool'
    }

    attribute_map = {
        'file_type': 'FileType',
        'display_name': 'DisplayName',
        'parent_folder_id': 'ParentFolderId',
        'description': 'Description',
        'location': 'Location',
        'corporation': 'Corporation',
        'group_ids': 'GroupIds',
        'id': 'Id',
        'file_name': 'FileName',
        'thumbnail_file_name': 'ThumbnailFileName',
        'creation_date': 'CreationDate',
        'update_date': 'UpdateDate',
        'file_count': 'FileCount',
        'folder_count': 'FolderCount',
        'is_root_folder': 'IsRootFolder',
        'tags': 'Tags',
        'image_height': 'ImageHeight',
        'image_width': 'ImageWidth',
        'is_primary_image': 'IsPrimaryImage'
    }

    def __init__(self, file_type=None, display_name=None, parent_folder_id=None, description=None, location=None, corporation=None, group_ids=None, id=None, file_name=None, thumbnail_file_name=None, creation_date=None, update_date=None, file_count=None, folder_count=None, is_root_folder=None, tags=None, image_height=None, image_width=None, is_primary_image=None):  # noqa: E501
        """PictureFileMetadataResponse - a model defined in Swagger"""  # noqa: E501
        self._file_type = None
        self._display_name = None
        self._parent_folder_id = None
        self._description = None
        self._location = None
        self._corporation = None
        self._group_ids = None
        self._id = None
        self._file_name = None
        self._thumbnail_file_name = None
        self._creation_date = None
        self._update_date = None
        self._file_count = None
        self._folder_count = None
        self._is_root_folder = None
        self._tags = None
        self._image_height = None
        self._image_width = None
        self._is_primary_image = None
        self.discriminator = None
        self.file_type = file_type
        self.display_name = display_name
        if parent_folder_id is not None:
            self.parent_folder_id = parent_folder_id
        if description is not None:
            self.description = description
        if location is not None:
            self.location = location
        if corporation is not None:
            self.corporation = corporation
        self.group_ids = group_ids
        self.id = id
        if file_name is not None:
            self.file_name = file_name
        if thumbnail_file_name is not None:
            self.thumbnail_file_name = thumbnail_file_name
        self.creation_date = creation_date
        self.update_date = update_date
        if file_count is not None:
            self.file_count = file_count
        if folder_count is not None:
            self.folder_count = folder_count
        self.is_root_folder = is_root_folder
        self.tags = tags
        if image_height is not None:
            self.image_height = image_height
        if image_width is not None:
            self.image_width = image_width
        if is_primary_image is not None:
            self.is_primary_image = is_primary_image

    @property
    def file_type(self):
        """Gets the file_type of this PictureFileMetadataResponse.  # noqa: E501


        :return: The file_type of this PictureFileMetadataResponse.  # noqa: E501
        :rtype: ContentType
        """
        return self._file_type

    @file_type.setter
    def file_type(self, file_type):
        """Sets the file_type of this PictureFileMetadataResponse.


        :param file_type: The file_type of this PictureFileMetadataResponse.  # noqa: E501
        :type: ContentType
        """
        if file_type is None:
            raise ValueError("Invalid value for `file_type`, must not be `None`")  # noqa: E501

        self._file_type = file_type

    @property
    def display_name(self):
        """Gets the display_name of this PictureFileMetadataResponse.  # noqa: E501

        Display name of the content  # noqa: E501

        :return: The display_name of this PictureFileMetadataResponse.  # noqa: E501
        :rtype: str
        """
        return self._display_name

    @display_name.setter
    def display_name(self, display_name):
        """Sets the display_name of this PictureFileMetadataResponse.

        Display name of the content  # noqa: E501

        :param display_name: The display_name of this PictureFileMetadataResponse.  # noqa: E501
        :type: str
        """
        if display_name is None:
            raise ValueError("Invalid value for `display_name`, must not be `None`")  # noqa: E501

        self._display_name = display_name

    @property
    def parent_folder_id(self):
        """Gets the parent_folder_id of this PictureFileMetadataResponse.  # noqa: E501

        Id of the content's parent folder  # noqa: E501

        :return: The parent_folder_id of this PictureFileMetadataResponse.  # noqa: E501
        :rtype: str
        """
        return self._parent_folder_id

    @parent_folder_id.setter
    def parent_folder_id(self, parent_folder_id):
        """Sets the parent_folder_id of this PictureFileMetadataResponse.

        Id of the content's parent folder  # noqa: E501

        :param parent_folder_id: The parent_folder_id of this PictureFileMetadataResponse.  # noqa: E501
        :type: str
        """

        self._parent_folder_id = parent_folder_id

    @property
    def description(self):
        """Gets the description of this PictureFileMetadataResponse.  # noqa: E501

        Description of the content  # noqa: E501

        :return: The description of this PictureFileMetadataResponse.  # noqa: E501
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this PictureFileMetadataResponse.

        Description of the content  # noqa: E501

        :param description: The description of this PictureFileMetadataResponse.  # noqa: E501
        :type: str
        """

        self._description = description

    @property
    def location(self):
        """Gets the location of this PictureFileMetadataResponse.  # noqa: E501


        :return: The location of this PictureFileMetadataResponse.  # noqa: E501
        :rtype: LocationChild
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this PictureFileMetadataResponse.


        :param location: The location of this PictureFileMetadataResponse.  # noqa: E501
        :type: LocationChild
        """

        self._location = location

    @property
    def corporation(self):
        """Gets the corporation of this PictureFileMetadataResponse.  # noqa: E501


        :return: The corporation of this PictureFileMetadataResponse.  # noqa: E501
        :rtype: CorporationChild
        """
        return self._corporation

    @corporation.setter
    def corporation(self, corporation):
        """Sets the corporation of this PictureFileMetadataResponse.


        :param corporation: The corporation of this PictureFileMetadataResponse.  # noqa: E501
        :type: CorporationChild
        """

        self._corporation = corporation

    @property
    def group_ids(self):
        """Gets the group_ids of this PictureFileMetadataResponse.  # noqa: E501

        Ids of groups the file belongs to  # noqa: E501

        :return: The group_ids of this PictureFileMetadataResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._group_ids

    @group_ids.setter
    def group_ids(self, group_ids):
        """Sets the group_ids of this PictureFileMetadataResponse.

        Ids of groups the file belongs to  # noqa: E501

        :param group_ids: The group_ids of this PictureFileMetadataResponse.  # noqa: E501
        :type: list[str]
        """
        if group_ids is None:
            raise ValueError("Invalid value for `group_ids`, must not be `None`")  # noqa: E501

        self._group_ids = group_ids

    @property
    def id(self):
        """Gets the id of this PictureFileMetadataResponse.  # noqa: E501

        Id of the content  # noqa: E501

        :return: The id of this PictureFileMetadataResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this PictureFileMetadataResponse.

        Id of the content  # noqa: E501

        :param id: The id of this PictureFileMetadataResponse.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def file_name(self):
        """Gets the file_name of this PictureFileMetadataResponse.  # noqa: E501

        File name that will be populated only if the content type is picture  # noqa: E501

        :return: The file_name of this PictureFileMetadataResponse.  # noqa: E501
        :rtype: str
        """
        return self._file_name

    @file_name.setter
    def file_name(self, file_name):
        """Sets the file_name of this PictureFileMetadataResponse.

        File name that will be populated only if the content type is picture  # noqa: E501

        :param file_name: The file_name of this PictureFileMetadataResponse.  # noqa: E501
        :type: str
        """

        self._file_name = file_name

    @property
    def thumbnail_file_name(self):
        """Gets the thumbnail_file_name of this PictureFileMetadataResponse.  # noqa: E501

        Thumbnail name that will be populated only if the content type is picture  # noqa: E501

        :return: The thumbnail_file_name of this PictureFileMetadataResponse.  # noqa: E501
        :rtype: str
        """
        return self._thumbnail_file_name

    @thumbnail_file_name.setter
    def thumbnail_file_name(self, thumbnail_file_name):
        """Sets the thumbnail_file_name of this PictureFileMetadataResponse.

        Thumbnail name that will be populated only if the content type is picture  # noqa: E501

        :param thumbnail_file_name: The thumbnail_file_name of this PictureFileMetadataResponse.  # noqa: E501
        :type: str
        """

        self._thumbnail_file_name = thumbnail_file_name

    @property
    def creation_date(self):
        """Gets the creation_date of this PictureFileMetadataResponse.  # noqa: E501

        Date the content was created  # noqa: E501

        :return: The creation_date of this PictureFileMetadataResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._creation_date

    @creation_date.setter
    def creation_date(self, creation_date):
        """Sets the creation_date of this PictureFileMetadataResponse.

        Date the content was created  # noqa: E501

        :param creation_date: The creation_date of this PictureFileMetadataResponse.  # noqa: E501
        :type: datetime
        """
        if creation_date is None:
            raise ValueError("Invalid value for `creation_date`, must not be `None`")  # noqa: E501

        self._creation_date = creation_date

    @property
    def update_date(self):
        """Gets the update_date of this PictureFileMetadataResponse.  # noqa: E501

        Date the content was last updated  # noqa: E501

        :return: The update_date of this PictureFileMetadataResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._update_date

    @update_date.setter
    def update_date(self, update_date):
        """Sets the update_date of this PictureFileMetadataResponse.

        Date the content was last updated  # noqa: E501

        :param update_date: The update_date of this PictureFileMetadataResponse.  # noqa: E501
        :type: datetime
        """
        if update_date is None:
            raise ValueError("Invalid value for `update_date`, must not be `None`")  # noqa: E501

        self._update_date = update_date

    @property
    def file_count(self):
        """Gets the file_count of this PictureFileMetadataResponse.  # noqa: E501

        Count of child files inside the folder if the content type is folder  # noqa: E501

        :return: The file_count of this PictureFileMetadataResponse.  # noqa: E501
        :rtype: int
        """
        return self._file_count

    @file_count.setter
    def file_count(self, file_count):
        """Sets the file_count of this PictureFileMetadataResponse.

        Count of child files inside the folder if the content type is folder  # noqa: E501

        :param file_count: The file_count of this PictureFileMetadataResponse.  # noqa: E501
        :type: int
        """

        self._file_count = file_count

    @property
    def folder_count(self):
        """Gets the folder_count of this PictureFileMetadataResponse.  # noqa: E501

        Count of child folders inside the folder if the content type is folder  # noqa: E501

        :return: The folder_count of this PictureFileMetadataResponse.  # noqa: E501
        :rtype: int
        """
        return self._folder_count

    @folder_count.setter
    def folder_count(self, folder_count):
        """Sets the folder_count of this PictureFileMetadataResponse.

        Count of child folders inside the folder if the content type is folder  # noqa: E501

        :param folder_count: The folder_count of this PictureFileMetadataResponse.  # noqa: E501
        :type: int
        """

        self._folder_count = folder_count

    @property
    def is_root_folder(self):
        """Gets the is_root_folder of this PictureFileMetadataResponse.  # noqa: E501

        Indicates if the folder is the root folder for folder content types. Picture types will  always be false.  # noqa: E501

        :return: The is_root_folder of this PictureFileMetadataResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_root_folder

    @is_root_folder.setter
    def is_root_folder(self, is_root_folder):
        """Sets the is_root_folder of this PictureFileMetadataResponse.

        Indicates if the folder is the root folder for folder content types. Picture types will  always be false.  # noqa: E501

        :param is_root_folder: The is_root_folder of this PictureFileMetadataResponse.  # noqa: E501
        :type: bool
        """
        if is_root_folder is None:
            raise ValueError("Invalid value for `is_root_folder`, must not be `None`")  # noqa: E501

        self._is_root_folder = is_root_folder

    @property
    def tags(self):
        """Gets the tags of this PictureFileMetadataResponse.  # noqa: E501

        List of tags associated with the content  # noqa: E501

        :return: The tags of this PictureFileMetadataResponse.  # noqa: E501
        :rtype: list[TagChild]
        """
        return self._tags

    @tags.setter
    def tags(self, tags):
        """Sets the tags of this PictureFileMetadataResponse.

        List of tags associated with the content  # noqa: E501

        :param tags: The tags of this PictureFileMetadataResponse.  # noqa: E501
        :type: list[TagChild]
        """
        if tags is None:
            raise ValueError("Invalid value for `tags`, must not be `None`")  # noqa: E501

        self._tags = tags

    @property
    def image_height(self):
        """Gets the image_height of this PictureFileMetadataResponse.  # noqa: E501

        Image height if the content type is picture  # noqa: E501

        :return: The image_height of this PictureFileMetadataResponse.  # noqa: E501
        :rtype: int
        """
        return self._image_height

    @image_height.setter
    def image_height(self, image_height):
        """Sets the image_height of this PictureFileMetadataResponse.

        Image height if the content type is picture  # noqa: E501

        :param image_height: The image_height of this PictureFileMetadataResponse.  # noqa: E501
        :type: int
        """

        self._image_height = image_height

    @property
    def image_width(self):
        """Gets the image_width of this PictureFileMetadataResponse.  # noqa: E501

        Image width if the content type is picture  # noqa: E501

        :return: The image_width of this PictureFileMetadataResponse.  # noqa: E501
        :rtype: int
        """
        return self._image_width

    @image_width.setter
    def image_width(self, image_width):
        """Sets the image_width of this PictureFileMetadataResponse.

        Image width if the content type is picture  # noqa: E501

        :param image_width: The image_width of this PictureFileMetadataResponse.  # noqa: E501
        :type: int
        """

        self._image_width = image_width

    @property
    def is_primary_image(self):
        """Gets the is_primary_image of this PictureFileMetadataResponse.  # noqa: E501

        Returns true if this file is a primary image for an asset. This property is only  populated if the request is made in the context of an asset.  # noqa: E501

        :return: The is_primary_image of this PictureFileMetadataResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_primary_image

    @is_primary_image.setter
    def is_primary_image(self, is_primary_image):
        """Sets the is_primary_image of this PictureFileMetadataResponse.

        Returns true if this file is a primary image for an asset. This property is only  populated if the request is made in the context of an asset.  # noqa: E501

        :param is_primary_image: The is_primary_image of this PictureFileMetadataResponse.  # noqa: E501
        :type: bool
        """

        self._is_primary_image = is_primary_image

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(PictureFileMetadataResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, PictureFileMetadataResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import re  # noqa: F401

# python 2 and python 3 compatibility library
import six

from smart_diagnostics_client.api_client import ApiClient


class PicturesApi(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def assign_pictures_to_group(self, group_id, **kwargs):  # noqa: E501
        """Associate an ordered list of pictures to a group  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.assign_pictures_to_group(group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str group_id: The GUID of the group to assign pictures to (required)
        :param list[str] body: An ordered list of picture GUIDs to associate with the group.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.assign_pictures_to_group_with_http_info(group_id, **kwargs)  # noqa: E501
        else:
            (data) = self.assign_pictures_to_group_with_http_info(group_id, **kwargs)  # noqa: E501
            return data

    def assign_pictures_to_group_with_http_info(self, group_id, **kwargs):  # noqa: E501
        """Associate an ordered list of pictures to a group  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.assign_pictures_to_group_with_http_info(group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str group_id: The GUID of the group to assign pictures to (required)
        :param list[str] body: An ordered list of picture GUIDs to associate with the group.
        :return: None
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['group_id', 'body']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method assign_pictures_to_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'group_id' is set
        if ('group_id' not in params or
                params['group_id'] is None):
            raise ValueError("Missing the required parameter `group_id` when calling `assign_pictures_to_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'group_id' in params:
            path_params['groupId'] = params['group_id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if 'body' in params:
            body_params = params['body']
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # HTTP header `Content-Type`
        header_params['Content-Type'] = self.api_client.select_header_content_type(  # noqa: E501
            ['application/json', 'text/json', 'application/*+json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Pictures/group/{groupId}', 'PUT',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type=None,  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_picture(self, id, **kwargs):  # noqa: E501
        """Returns a single picture  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_picture(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Picture Id (required)
        :return: PicturesModelV3
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_picture_with_http_info(id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_picture_with_http_info(id, **kwargs)  # noqa: E501
            return data

    def get_picture_with_http_info(self, id, **kwargs):  # noqa: E501
        """Returns a single picture  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_picture_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Picture Id (required)
        :return: PicturesModelV3
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['id']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_picture" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'id' is set
        if ('id' not in params or
                params['id'] is None):
            raise ValueError("Missing the required parameter `id` when calling `get_picture`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'id' in params:
            path_params['id'] = params['id']  # noqa: E501

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Pictures/{id}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PicturesModelV3',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_pictures(self, **kwargs):  # noqa: E501
        """Returns a paged list of all pictures  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_pictures(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `Id` | Guid | `eq, neq, in` | | `ImageFileName` | String | `eq, neq, in, like, isnull, isnotnull` | | `Name` | String | `eq, neq, in, like, isnull, isnotnull` | | `ThumbnailFileName` | String | `eq, neq, in, like, isnull, isnotnull` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `Id` | Guid | | `ImageFileName` | String | | `Name` | String | | `ThumbnailFileName` | String |
        :param str name_search: Provide search terms to narrow result.  Searchable properties: `ImageFileName`, `Name`.
        :return: PagedResultsModelPicturesModelV3
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_pictures_with_http_info(**kwargs)  # noqa: E501
        else:
            (data) = self.get_pictures_with_http_info(**kwargs)  # noqa: E501
            return data

    def get_pictures_with_http_info(self, **kwargs):  # noqa: E501
        """Returns a paged list of all pictures  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_pictures_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `Id` | Guid | `eq, neq, in` | | `ImageFileName` | String | `eq, neq, in, like, isnull, isnotnull` | | `Name` | String | `eq, neq, in, like, isnull, isnotnull` | | `ThumbnailFileName` | String | `eq, neq, in, like, isnull, isnotnull` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `Id` | Guid | | `ImageFileName` | String | | `Name` | String | | `ThumbnailFileName` | String |
        :param str name_search: Provide search terms to narrow result.  Searchable properties: `ImageFileName`, `Name`.
        :return: PagedResultsModelPicturesModelV3
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['filter', 'page', 'page_limit', 'order_by', 'name_search']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_pictures" % key
                )
            params[key] = val
        del params['kwargs']

        collection_formats = {}

        path_params = {}

        query_params = []
        if 'filter' in params:
            query_params.append(('Filter', params['filter']))  # noqa: E501
        if 'page' in params:
            query_params.append(('Page', params['page']))  # noqa: E501
        if 'page_limit' in params:
            query_params.append(('PageLimit', params['page_limit']))  # noqa: E501
        if 'order_by' in params:
            query_params.append(('OrderBy', params['order_by']))  # noqa: E501
        if 'name_search' in params:
            query_params.append(('NameSearch', params['name_search']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Pictures', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PagedResultsModelPicturesModelV3',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_pictures_for_group(self, group_id, **kwargs):  # noqa: E501
        """Get a paged list of pictures associated with a group  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_pictures_for_group(group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str group_id: The GUID of the group (required)
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `Id` | Guid | `eq, neq, in` | | `ImageFileName` | String | `eq, neq, in, like, isnull, isnotnull` | | `Name` | String | `eq, neq, in, like, isnull, isnotnull` | | `ThumbnailFileName` | String | `eq, neq, in, like, isnull, isnotnull` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `Id` | Guid | | `ImageFileName` | String | | `Name` | String | | `ThumbnailFileName` | String |
        :return: PagedResultsModelPicturesModelV3
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_pictures_for_group_with_http_info(group_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_pictures_for_group_with_http_info(group_id, **kwargs)  # noqa: E501
            return data

    def get_pictures_for_group_with_http_info(self, group_id, **kwargs):  # noqa: E501
        """Get a paged list of pictures associated with a group  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_pictures_for_group_with_http_info(group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str group_id: The GUID of the group (required)
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `Id` | Guid | `eq, neq, in` | | `ImageFileName` | String | `eq, neq, in, like, isnull, isnotnull` | | `Name` | String | `eq, neq, in, like, isnull, isnotnull` | | `ThumbnailFileName` | String | `eq, neq, in, like, isnull, isnotnull` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `Id` | Guid | | `ImageFileName` | String | | `Name` | String | | `ThumbnailFileName` | String |
        :return: PagedResultsModelPicturesModelV3
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['group_id', 'filter', 'page', 'page_limit', 'order_by']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_pictures_for_group" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'group_id' is set
        if ('group_id' not in params or
                params['group_id'] is None):
            raise ValueError("Missing the required parameter `group_id` when calling `get_pictures_for_group`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'group_id' in params:
            path_params['groupId'] = params['group_id']  # noqa: E501

        query_params = []
        if 'filter' in params:
            query_params.append(('Filter', params['filter']))  # noqa: E501
        if 'page' in params:
            query_params.append(('Page', params['page']))  # noqa: E501
        if 'page_limit' in params:
            query_params.append(('PageLimit', params['page_limit']))  # noqa: E501
        if 'order_by' in params:
            query_params.append(('OrderBy', params['order_by']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Pictures/group/{groupId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PagedResultsModelPicturesModelV3',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)

    def get_pictures_for_location(self, location_id, **kwargs):  # noqa: E501
        """Returns a paged list of pictures associated with an account  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_pictures_for_location(location_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str location_id: The GUID of the account/location (required)
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `Id` | Guid | `eq, neq, in` | | `ImageFileName` | String | `eq, neq, in, like, isnull, isnotnull` | | `Name` | String | `eq, neq, in, like, isnull, isnotnull` | | `ThumbnailFileName` | String | `eq, neq, in, like, isnull, isnotnull` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `Id` | Guid | | `ImageFileName` | String | | `Name` | String | | `ThumbnailFileName` | String |
        :param str name_search: Provide search terms to narrow result.  Searchable properties: `ImageFileName`, `Name`.
        :return: PagedResultsModelPicturesModelV3
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs['_return_http_data_only'] = True
        if kwargs.get('async_req'):
            return self.get_pictures_for_location_with_http_info(location_id, **kwargs)  # noqa: E501
        else:
            (data) = self.get_pictures_for_location_with_http_info(location_id, **kwargs)  # noqa: E501
            return data

    def get_pictures_for_location_with_http_info(self, location_id, **kwargs):  # noqa: E501
        """Returns a paged list of pictures associated with an account  # noqa: E501

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.get_pictures_for_location_with_http_info(location_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str location_id: The GUID of the account/location (required)
        :param str filter: Filter statements to narrow results by properties. Filterable properties:  | Field name | Type | Operators | | ---------- | ---- | --------- | | `Id` | Guid | `eq, neq, in` | | `ImageFileName` | String | `eq, neq, in, like, isnull, isnotnull` | | `Name` | String | `eq, neq, in, like, isnull, isnotnull` | | `ThumbnailFileName` | String | `eq, neq, in, like, isnull, isnotnull` |
        :param int page: Results page. 1-based (1 returns the first page, 0 is invalid).
        :param int page_limit: Number of items to return per page.
        :param str order_by: Allows sorting response items by multiple fields. Sortable properties: | Field name | Type | | ---------- | ---- | | `Id` | Guid | | `ImageFileName` | String | | `Name` | String | | `ThumbnailFileName` | String |
        :param str name_search: Provide search terms to narrow result.  Searchable properties: `ImageFileName`, `Name`.
        :return: PagedResultsModelPicturesModelV3
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ['location_id', 'filter', 'page', 'page_limit', 'order_by', 'name_search']  # noqa: E501
        all_params.append('async_req')
        all_params.append('_return_http_data_only')
        all_params.append('_preload_content')
        all_params.append('_request_timeout')

        params = locals()
        for key, val in six.iteritems(params['kwargs']):
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method get_pictures_for_location" % key
                )
            params[key] = val
        del params['kwargs']
        # verify the required parameter 'location_id' is set
        if ('location_id' not in params or
                params['location_id'] is None):
            raise ValueError("Missing the required parameter `location_id` when calling `get_pictures_for_location`")  # noqa: E501

        collection_formats = {}

        path_params = {}
        if 'location_id' in params:
            path_params['locationId'] = params['location_id']  # noqa: E501

        query_params = []
        if 'filter' in params:
            query_params.append(('Filter', params['filter']))  # noqa: E501
        if 'page' in params:
            query_params.append(('Page', params['page']))  # noqa: E501
        if 'page_limit' in params:
            query_params.append(('PageLimit', params['page_limit']))  # noqa: E501
        if 'order_by' in params:
            query_params.append(('OrderBy', params['order_by']))  # noqa: E501
        if 'name_search' in params:
            query_params.append(('NameSearch', params['name_search']))  # noqa: E501

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params['Accept'] = self.api_client.select_header_accept(
            ['text/plain', 'application/json', 'text/json'])  # noqa: E501

        # Authentication setting
        auth_settings = []  # noqa: E501

        return self.api_client.call_api(
            '/api/v3.0/Pictures/location/{locationId}', 'GET',
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type='PagedResultsModelPicturesModelV3',  # noqa: E501
            auth_settings=auth_settings,
            async_req=params.get('async_req'),
            _return_http_data_only=params.get('_return_http_data_only'),
            _preload_content=params.get('_preload_content', True),
            _request_timeout=params.get('_request_timeout'),
            collection_formats=collection_formats)



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ModelAssignmentUpdateRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'properties': 'list[SetPropertyChild]',
        'assigned_group_ids': 'list[str]'
    }

    attribute_map = {
        'properties': 'Properties',
        'assigned_group_ids': 'AssignedGroupIds'
    }

    def __init__(self, properties=None, assigned_group_ids=None):  # noqa: E501
        """ModelAssignmentUpdateRequest - a model defined in Swagger"""  # noqa: E501
        self._properties = None
        self._assigned_group_ids = None
        self.discriminator = None
        self.properties = properties
        self.assigned_group_ids = assigned_group_ids

    @property
    def properties(self):
        """Gets the properties of this ModelAssignmentUpdateRequest.  # noqa: E501

        Property values for the model assignment  # noqa: E501

        :return: The properties of this ModelAssignmentUpdateRequest.  # noqa: E501
        :rtype: list[SetPropertyChild]
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """Sets the properties of this ModelAssignmentUpdateRequest.

        Property values for the model assignment  # noqa: E501

        :param properties: The properties of this ModelAssignmentUpdateRequest.  # noqa: E501
        :type: list[SetPropertyChild]
        """
        if properties is None:
            raise ValueError("Invalid value for `properties`, must not be `None`")  # noqa: E501

        self._properties = properties

    @property
    def assigned_group_ids(self):
        """Gets the assigned_group_ids of this ModelAssignmentUpdateRequest.  # noqa: E501

        Groups that provide data for the model assignment. They must be the assignment group's parent or its descendants  and must be Monitoring Point, Asset, or Group type.  # noqa: E501

        :return: The assigned_group_ids of this ModelAssignmentUpdateRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._assigned_group_ids

    @assigned_group_ids.setter
    def assigned_group_ids(self, assigned_group_ids):
        """Sets the assigned_group_ids of this ModelAssignmentUpdateRequest.

        Groups that provide data for the model assignment. They must be the assignment group's parent or its descendants  and must be Monitoring Point, Asset, or Group type.  # noqa: E501

        :param assigned_group_ids: The assigned_group_ids of this ModelAssignmentUpdateRequest.  # noqa: E501
        :type: list[str]
        """
        if assigned_group_ids is None:
            raise ValueError("Invalid value for `assigned_group_ids`, must not be `None`")  # noqa: E501

        self._assigned_group_ids = assigned_group_ids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ModelAssignmentUpdateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ModelAssignmentUpdateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class AnalyticsModelCreateRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'name': 'str',
        'version': 'str',
        'location_id': 'str',
        'corporation_id': 'str',
        'group_type': 'GroupTypeCodes',
        'indicators': 'list[AnalyticsModelIndicatorChild]',
        'properties': 'list[PropertyRequestChild]',
        'trigger_interval_in_seconds': 'int',
        'tag_ids': 'list[str]'
    }

    attribute_map = {
        'name': 'Name',
        'version': 'Version',
        'location_id': 'LocationId',
        'corporation_id': 'CorporationId',
        'group_type': 'GroupType',
        'indicators': 'Indicators',
        'properties': 'Properties',
        'trigger_interval_in_seconds': 'TriggerIntervalInSeconds',
        'tag_ids': 'TagIds'
    }

    def __init__(self, name=None, version=None, location_id=None, corporation_id=None, group_type=None, indicators=None, properties=None, trigger_interval_in_seconds=None, tag_ids=None):  # noqa: E501
        """AnalyticsModelCreateRequest - a model defined in Swagger"""  # noqa: E501
        self._name = None
        self._version = None
        self._location_id = None
        self._corporation_id = None
        self._group_type = None
        self._indicators = None
        self._properties = None
        self._trigger_interval_in_seconds = None
        self._tag_ids = None
        self.discriminator = None
        self.name = name
        self.version = version
        if location_id is not None:
            self.location_id = location_id
        if corporation_id is not None:
            self.corporation_id = corporation_id
        self.group_type = group_type
        if indicators is not None:
            self.indicators = indicators
        if properties is not None:
            self.properties = properties
        self.trigger_interval_in_seconds = trigger_interval_in_seconds
        if tag_ids is not None:
            self.tag_ids = tag_ids

    @property
    def name(self):
        """Gets the name of this AnalyticsModelCreateRequest.  # noqa: E501


        :return: The name of this AnalyticsModelCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this AnalyticsModelCreateRequest.


        :param name: The name of this AnalyticsModelCreateRequest.  # noqa: E501
        :type: str
        """
        if name is None:
            raise ValueError("Invalid value for `name`, must not be `None`")  # noqa: E501

        self._name = name

    @property
    def version(self):
        """Gets the version of this AnalyticsModelCreateRequest.  # noqa: E501


        :return: The version of this AnalyticsModelCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._version

    @version.setter
    def version(self, version):
        """Sets the version of this AnalyticsModelCreateRequest.


        :param version: The version of this AnalyticsModelCreateRequest.  # noqa: E501
        :type: str
        """
        if version is None:
            raise ValueError("Invalid value for `version`, must not be `None`")  # noqa: E501

        self._version = version

    @property
    def location_id(self):
        """Gets the location_id of this AnalyticsModelCreateRequest.  # noqa: E501


        :return: The location_id of this AnalyticsModelCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._location_id

    @location_id.setter
    def location_id(self, location_id):
        """Sets the location_id of this AnalyticsModelCreateRequest.


        :param location_id: The location_id of this AnalyticsModelCreateRequest.  # noqa: E501
        :type: str
        """

        self._location_id = location_id

    @property
    def corporation_id(self):
        """Gets the corporation_id of this AnalyticsModelCreateRequest.  # noqa: E501


        :return: The corporation_id of this AnalyticsModelCreateRequest.  # noqa: E501
        :rtype: str
        """
        return self._corporation_id

    @corporation_id.setter
    def corporation_id(self, corporation_id):
        """Sets the corporation_id of this AnalyticsModelCreateRequest.


        :param corporation_id: The corporation_id of this AnalyticsModelCreateRequest.  # noqa: E501
        :type: str
        """

        self._corporation_id = corporation_id

    @property
    def group_type(self):
        """Gets the group_type of this AnalyticsModelCreateRequest.  # noqa: E501


        :return: The group_type of this AnalyticsModelCreateRequest.  # noqa: E501
        :rtype: GroupTypeCodes
        """
        return self._group_type

    @group_type.setter
    def group_type(self, group_type):
        """Sets the group_type of this AnalyticsModelCreateRequest.


        :param group_type: The group_type of this AnalyticsModelCreateRequest.  # noqa: E501
        :type: GroupTypeCodes
        """
        if group_type is None:
            raise ValueError("Invalid value for `group_type`, must not be `None`")  # noqa: E501

        self._group_type = group_type

    @property
    def indicators(self):
        """Gets the indicators of this AnalyticsModelCreateRequest.  # noqa: E501


        :return: The indicators of this AnalyticsModelCreateRequest.  # noqa: E501
        :rtype: list[AnalyticsModelIndicatorChild]
        """
        return self._indicators

    @indicators.setter
    def indicators(self, indicators):
        """Sets the indicators of this AnalyticsModelCreateRequest.


        :param indicators: The indicators of this AnalyticsModelCreateRequest.  # noqa: E501
        :type: list[AnalyticsModelIndicatorChild]
        """

        self._indicators = indicators

    @property
    def properties(self):
        """Gets the properties of this AnalyticsModelCreateRequest.  # noqa: E501


        :return: The properties of this AnalyticsModelCreateRequest.  # noqa: E501
        :rtype: list[PropertyRequestChild]
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """Sets the properties of this AnalyticsModelCreateRequest.


        :param properties: The properties of this AnalyticsModelCreateRequest.  # noqa: E501
        :type: list[PropertyRequestChild]
        """

        self._properties = properties

    @property
    def trigger_interval_in_seconds(self):
        """Gets the trigger_interval_in_seconds of this AnalyticsModelCreateRequest.  # noqa: E501


        :return: The trigger_interval_in_seconds of this AnalyticsModelCreateRequest.  # noqa: E501
        :rtype: int
        """
        return self._trigger_interval_in_seconds

    @trigger_interval_in_seconds.setter
    def trigger_interval_in_seconds(self, trigger_interval_in_seconds):
        """Sets the trigger_interval_in_seconds of this AnalyticsModelCreateRequest.


        :param trigger_interval_in_seconds: The trigger_interval_in_seconds of this AnalyticsModelCreateRequest.  # noqa: E501
        :type: int
        """
        if trigger_interval_in_seconds is None:
            raise ValueError("Invalid value for `trigger_interval_in_seconds`, must not be `None`")  # noqa: E501

        self._trigger_interval_in_seconds = trigger_interval_in_seconds

    @property
    def tag_ids(self):
        """Gets the tag_ids of this AnalyticsModelCreateRequest.  # noqa: E501


        :return: The tag_ids of this AnalyticsModelCreateRequest.  # noqa: E501
        :rtype: list[str]
        """
        return self._tag_ids

    @tag_ids.setter
    def tag_ids(self, tag_ids):
        """Sets the tag_ids of this AnalyticsModelCreateRequest.


        :param tag_ids: The tag_ids of this AnalyticsModelCreateRequest.  # noqa: E501
        :type: list[str]
        """

        self._tag_ids = tag_ids

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(AnalyticsModelCreateRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, AnalyticsModelCreateRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.events_api import EventsApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestEventsApi(unittest.TestCase):
    """EventsApi unit test stubs"""

    def setUp(self):
        self.api = EventsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_create_event(self):
        """Test case for create_event

        This route is obsolete. Please use /api/v3.0/Activities instead.  Creates an event  # noqa: E501
        """
        pass

    def test_export_events(self):
        """Test case for export_events

        Enqueues a report that contains all events for the params  # noqa: E501
        """
        pass

    def test_update_event(self):
        """Test case for update_event

        Updates an Event  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ModelAssignmentResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'model': 'AnalyticsModelChild',
        'assigned_group_ids': 'list[str]',
        'properties': 'list[PropertyChild]',
        'indicators': 'list[ModelAssignmentIndicatorChild]',
        'created_date': 'datetime',
        'created_by': 'UserChild',
        'analytics_group': 'GroupChild',
        'location': 'LocationChild',
        'corporation': 'CorporationChild'
    }

    attribute_map = {
        'id': 'Id',
        'model': 'Model',
        'assigned_group_ids': 'AssignedGroupIds',
        'properties': 'Properties',
        'indicators': 'Indicators',
        'created_date': 'CreatedDate',
        'created_by': 'CreatedBy',
        'analytics_group': 'AnalyticsGroup',
        'location': 'Location',
        'corporation': 'Corporation'
    }

    def __init__(self, id=None, model=None, assigned_group_ids=None, properties=None, indicators=None, created_date=None, created_by=None, analytics_group=None, location=None, corporation=None):  # noqa: E501
        """ModelAssignmentResponse - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._model = None
        self._assigned_group_ids = None
        self._properties = None
        self._indicators = None
        self._created_date = None
        self._created_by = None
        self._analytics_group = None
        self._location = None
        self._corporation = None
        self.discriminator = None
        self.id = id
        self.model = model
        self.assigned_group_ids = assigned_group_ids
        self.properties = properties
        self.indicators = indicators
        self.created_date = created_date
        self.created_by = created_by
        self.analytics_group = analytics_group
        self.location = location
        self.corporation = corporation

    @property
    def id(self):
        """Gets the id of this ModelAssignmentResponse.  # noqa: E501

        Id of the assignment  # noqa: E501

        :return: The id of this ModelAssignmentResponse.  # noqa: E501
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this ModelAssignmentResponse.

        Id of the assignment  # noqa: E501

        :param id: The id of this ModelAssignmentResponse.  # noqa: E501
        :type: str
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def model(self):
        """Gets the model of this ModelAssignmentResponse.  # noqa: E501


        :return: The model of this ModelAssignmentResponse.  # noqa: E501
        :rtype: AnalyticsModelChild
        """
        return self._model

    @model.setter
    def model(self, model):
        """Sets the model of this ModelAssignmentResponse.


        :param model: The model of this ModelAssignmentResponse.  # noqa: E501
        :type: AnalyticsModelChild
        """
        if model is None:
            raise ValueError("Invalid value for `model`, must not be `None`")  # noqa: E501

        self._model = model

    @property
    def assigned_group_ids(self):
        """Gets the assigned_group_ids of this ModelAssignmentResponse.  # noqa: E501

        List of group ids that provide data to the model assignment  # noqa: E501

        :return: The assigned_group_ids of this ModelAssignmentResponse.  # noqa: E501
        :rtype: list[str]
        """
        return self._assigned_group_ids

    @assigned_group_ids.setter
    def assigned_group_ids(self, assigned_group_ids):
        """Sets the assigned_group_ids of this ModelAssignmentResponse.

        List of group ids that provide data to the model assignment  # noqa: E501

        :param assigned_group_ids: The assigned_group_ids of this ModelAssignmentResponse.  # noqa: E501
        :type: list[str]
        """
        if assigned_group_ids is None:
            raise ValueError("Invalid value for `assigned_group_ids`, must not be `None`")  # noqa: E501

        self._assigned_group_ids = assigned_group_ids

    @property
    def properties(self):
        """Gets the properties of this ModelAssignmentResponse.  # noqa: E501

        List of properties for the model assignment  # noqa: E501

        :return: The properties of this ModelAssignmentResponse.  # noqa: E501
        :rtype: list[PropertyChild]
        """
        return self._properties

    @properties.setter
    def properties(self, properties):
        """Sets the properties of this ModelAssignmentResponse.

        List of properties for the model assignment  # noqa: E501

        :param properties: The properties of this ModelAssignmentResponse.  # noqa: E501
        :type: list[PropertyChild]
        """
        if properties is None:
            raise ValueError("Invalid value for `properties`, must not be `None`")  # noqa: E501

        self._properties = properties

    @property
    def indicators(self):
        """Gets the indicators of this ModelAssignmentResponse.  # noqa: E501

        List of indicators on the assignment  # noqa: E501

        :return: The indicators of this ModelAssignmentResponse.  # noqa: E501
        :rtype: list[ModelAssignmentIndicatorChild]
        """
        return self._indicators

    @indicators.setter
    def indicators(self, indicators):
        """Sets the indicators of this ModelAssignmentResponse.

        List of indicators on the assignment  # noqa: E501

        :param indicators: The indicators of this ModelAssignmentResponse.  # noqa: E501
        :type: list[ModelAssignmentIndicatorChild]
        """
        if indicators is None:
            raise ValueError("Invalid value for `indicators`, must not be `None`")  # noqa: E501

        self._indicators = indicators

    @property
    def created_date(self):
        """Gets the created_date of this ModelAssignmentResponse.  # noqa: E501

        Date model assignment was created  # noqa: E501

        :return: The created_date of this ModelAssignmentResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._created_date

    @created_date.setter
    def created_date(self, created_date):
        """Sets the created_date of this ModelAssignmentResponse.

        Date model assignment was created  # noqa: E501

        :param created_date: The created_date of this ModelAssignmentResponse.  # noqa: E501
        :type: datetime
        """
        if created_date is None:
            raise ValueError("Invalid value for `created_date`, must not be `None`")  # noqa: E501

        self._created_date = created_date

    @property
    def created_by(self):
        """Gets the created_by of this ModelAssignmentResponse.  # noqa: E501


        :return: The created_by of this ModelAssignmentResponse.  # noqa: E501
        :rtype: UserChild
        """
        return self._created_by

    @created_by.setter
    def created_by(self, created_by):
        """Sets the created_by of this ModelAssignmentResponse.


        :param created_by: The created_by of this ModelAssignmentResponse.  # noqa: E501
        :type: UserChild
        """
        if created_by is None:
            raise ValueError("Invalid value for `created_by`, must not be `None`")  # noqa: E501

        self._created_by = created_by

    @property
    def analytics_group(self):
        """Gets the analytics_group of this ModelAssignmentResponse.  # noqa: E501


        :return: The analytics_group of this ModelAssignmentResponse.  # noqa: E501
        :rtype: GroupChild
        """
        return self._analytics_group

    @analytics_group.setter
    def analytics_group(self, analytics_group):
        """Sets the analytics_group of this ModelAssignmentResponse.


        :param analytics_group: The analytics_group of this ModelAssignmentResponse.  # noqa: E501
        :type: GroupChild
        """
        if analytics_group is None:
            raise ValueError("Invalid value for `analytics_group`, must not be `None`")  # noqa: E501

        self._analytics_group = analytics_group

    @property
    def location(self):
        """Gets the location of this ModelAssignmentResponse.  # noqa: E501


        :return: The location of this ModelAssignmentResponse.  # noqa: E501
        :rtype: LocationChild
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this ModelAssignmentResponse.


        :param location: The location of this ModelAssignmentResponse.  # noqa: E501
        :type: LocationChild
        """
        if location is None:
            raise ValueError("Invalid value for `location`, must not be `None`")  # noqa: E501

        self._location = location

    @property
    def corporation(self):
        """Gets the corporation of this ModelAssignmentResponse.  # noqa: E501


        :return: The corporation of this ModelAssignmentResponse.  # noqa: E501
        :rtype: CorporationChild
        """
        return self._corporation

    @corporation.setter
    def corporation(self, corporation):
        """Sets the corporation of this ModelAssignmentResponse.


        :param corporation: The corporation of this ModelAssignmentResponse.  # noqa: E501
        :type: CorporationChild
        """
        if corporation is None:
            raise ValueError("Invalid value for `corporation`, must not be `None`")  # noqa: E501

        self._corporation = corporation

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ModelAssignmentResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ModelAssignmentResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.tree_items_api import TreeItemsApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestTreeItemsApi(unittest.TestCase):
    """TreeItemsApi unit test stubs"""

    def setUp(self):
        self.api = TreeItemsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_delete_tree_item(self):
        """Test case for delete_tree_item

        Deletes a treeItem  # noqa: E501
        """
        pass

    def test_get_tree_item(self):
        """Test case for get_tree_item

        Gets a treeItem  # noqa: E501
        """
        pass

    def test_get_tree_item_available_asset_classes(self):
        """Test case for get_tree_item_available_asset_classes

        Gets available asset classes in the subtree rooted at treeItemId  # noqa: E501
        """
        pass

    def test_get_tree_item_children(self):
        """Test case for get_tree_item_children

        Gets the child groups under a TreeItem  # noqa: E501
        """
        pass

    def test_move_tree_item(self):
        """Test case for move_tree_item

        Moves a treeItem  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class UserProfileResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'user_id': 'str',
        'acceleration_units': 'str',
        'date_format': 'str',
        'pressure_units': 'str',
        'temperature_units': 'str',
        'time_format': 'str',
        'time_zone': 'str',
        'velocity_units': 'str'
    }

    attribute_map = {
        'user_id': 'UserId',
        'acceleration_units': 'AccelerationUnits',
        'date_format': 'DateFormat',
        'pressure_units': 'PressureUnits',
        'temperature_units': 'TemperatureUnits',
        'time_format': 'TimeFormat',
        'time_zone': 'TimeZone',
        'velocity_units': 'VelocityUnits'
    }

    def __init__(self, user_id=None, acceleration_units=None, date_format=None, pressure_units=None, temperature_units=None, time_format=None, time_zone=None, velocity_units=None):  # noqa: E501
        """UserProfileResponse - a model defined in Swagger"""  # noqa: E501
        self._user_id = None
        self._acceleration_units = None
        self._date_format = None
        self._pressure_units = None
        self._temperature_units = None
        self._time_format = None
        self._time_zone = None
        self._velocity_units = None
        self.discriminator = None
        self.user_id = user_id
        self.acceleration_units = acceleration_units
        self.date_format = date_format
        self.pressure_units = pressure_units
        self.temperature_units = temperature_units
        self.time_format = time_format
        self.time_zone = time_zone
        self.velocity_units = velocity_units

    @property
    def user_id(self):
        """Gets the user_id of this UserProfileResponse.  # noqa: E501

        User ID  # noqa: E501

        :return: The user_id of this UserProfileResponse.  # noqa: E501
        :rtype: str
        """
        return self._user_id

    @user_id.setter
    def user_id(self, user_id):
        """Sets the user_id of this UserProfileResponse.

        User ID  # noqa: E501

        :param user_id: The user_id of this UserProfileResponse.  # noqa: E501
        :type: str
        """
        if user_id is None:
            raise ValueError("Invalid value for `user_id`, must not be `None`")  # noqa: E501

        self._user_id = user_id

    @property
    def acceleration_units(self):
        """Gets the acceleration_units of this UserProfileResponse.  # noqa: E501

        Acceleration units  # noqa: E501

        :return: The acceleration_units of this UserProfileResponse.  # noqa: E501
        :rtype: str
        """
        return self._acceleration_units

    @acceleration_units.setter
    def acceleration_units(self, acceleration_units):
        """Sets the acceleration_units of this UserProfileResponse.

        Acceleration units  # noqa: E501

        :param acceleration_units: The acceleration_units of this UserProfileResponse.  # noqa: E501
        :type: str
        """
        if acceleration_units is None:
            raise ValueError("Invalid value for `acceleration_units`, must not be `None`")  # noqa: E501

        self._acceleration_units = acceleration_units

    @property
    def date_format(self):
        """Gets the date_format of this UserProfileResponse.  # noqa: E501

        Date format  # noqa: E501

        :return: The date_format of this UserProfileResponse.  # noqa: E501
        :rtype: str
        """
        return self._date_format

    @date_format.setter
    def date_format(self, date_format):
        """Sets the date_format of this UserProfileResponse.

        Date format  # noqa: E501

        :param date_format: The date_format of this UserProfileResponse.  # noqa: E501
        :type: str
        """
        if date_format is None:
            raise ValueError("Invalid value for `date_format`, must not be `None`")  # noqa: E501

        self._date_format = date_format

    @property
    def pressure_units(self):
        """Gets the pressure_units of this UserProfileResponse.  # noqa: E501

        Pressure units  # noqa: E501

        :return: The pressure_units of this UserProfileResponse.  # noqa: E501
        :rtype: str
        """
        return self._pressure_units

    @pressure_units.setter
    def pressure_units(self, pressure_units):
        """Sets the pressure_units of this UserProfileResponse.

        Pressure units  # noqa: E501

        :param pressure_units: The pressure_units of this UserProfileResponse.  # noqa: E501
        :type: str
        """
        if pressure_units is None:
            raise ValueError("Invalid value for `pressure_units`, must not be `None`")  # noqa: E501

        self._pressure_units = pressure_units

    @property
    def temperature_units(self):
        """Gets the temperature_units of this UserProfileResponse.  # noqa: E501

        Temperature units  # noqa: E501

        :return: The temperature_units of this UserProfileResponse.  # noqa: E501
        :rtype: str
        """
        return self._temperature_units

    @temperature_units.setter
    def temperature_units(self, temperature_units):
        """Sets the temperature_units of this UserProfileResponse.

        Temperature units  # noqa: E501

        :param temperature_units: The temperature_units of this UserProfileResponse.  # noqa: E501
        :type: str
        """
        if temperature_units is None:
            raise ValueError("Invalid value for `temperature_units`, must not be `None`")  # noqa: E501

        self._temperature_units = temperature_units

    @property
    def time_format(self):
        """Gets the time_format of this UserProfileResponse.  # noqa: E501

        Time format  # noqa: E501

        :return: The time_format of this UserProfileResponse.  # noqa: E501
        :rtype: str
        """
        return self._time_format

    @time_format.setter
    def time_format(self, time_format):
        """Sets the time_format of this UserProfileResponse.

        Time format  # noqa: E501

        :param time_format: The time_format of this UserProfileResponse.  # noqa: E501
        :type: str
        """
        if time_format is None:
            raise ValueError("Invalid value for `time_format`, must not be `None`")  # noqa: E501

        self._time_format = time_format

    @property
    def time_zone(self):
        """Gets the time_zone of this UserProfileResponse.  # noqa: E501

        Time zone  # noqa: E501

        :return: The time_zone of this UserProfileResponse.  # noqa: E501
        :rtype: str
        """
        return self._time_zone

    @time_zone.setter
    def time_zone(self, time_zone):
        """Sets the time_zone of this UserProfileResponse.

        Time zone  # noqa: E501

        :param time_zone: The time_zone of this UserProfileResponse.  # noqa: E501
        :type: str
        """
        if time_zone is None:
            raise ValueError("Invalid value for `time_zone`, must not be `None`")  # noqa: E501

        self._time_zone = time_zone

    @property
    def velocity_units(self):
        """Gets the velocity_units of this UserProfileResponse.  # noqa: E501

        Velocity units  # noqa: E501

        :return: The velocity_units of this UserProfileResponse.  # noqa: E501
        :rtype: str
        """
        return self._velocity_units

    @velocity_units.setter
    def velocity_units(self, velocity_units):
        """Sets the velocity_units of this UserProfileResponse.

        Velocity units  # noqa: E501

        :param velocity_units: The velocity_units of this UserProfileResponse.  # noqa: E501
        :type: str
        """
        if velocity_units is None:
            raise ValueError("Invalid value for `velocity_units`, must not be `None`")  # noqa: E501

        self._velocity_units = velocity_units

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(UserProfileResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserProfileResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class RepeaterResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'int',
        'name': 'str',
        'serial_number': 'str',
        'radio_mac_address': 'str',
        'last_status_update': 'datetime',
        'active': 'bool',
        'software_version': 'str',
        'online_node_count': 'int',
        'location': 'LocationChild',
        'corporation': 'CorporationChild',
        'base_station': 'BaseStationChild',
        'is_online': 'bool'
    }

    attribute_map = {
        'id': 'Id',
        'name': 'Name',
        'serial_number': 'SerialNumber',
        'radio_mac_address': 'RadioMacAddress',
        'last_status_update': 'LastStatusUpdate',
        'active': 'Active',
        'software_version': 'SoftwareVersion',
        'online_node_count': 'OnlineNodeCount',
        'location': 'Location',
        'corporation': 'Corporation',
        'base_station': 'BaseStation',
        'is_online': 'IsOnline'
    }

    def __init__(self, id=None, name=None, serial_number=None, radio_mac_address=None, last_status_update=None, active=None, software_version=None, online_node_count=None, location=None, corporation=None, base_station=None, is_online=None):  # noqa: E501
        """RepeaterResponse - a model defined in Swagger"""  # noqa: E501
        self._id = None
        self._name = None
        self._serial_number = None
        self._radio_mac_address = None
        self._last_status_update = None
        self._active = None
        self._software_version = None
        self._online_node_count = None
        self._location = None
        self._corporation = None
        self._base_station = None
        self._is_online = None
        self.discriminator = None
        self.id = id
        if name is not None:
            self.name = name
        self.serial_number = serial_number
        if radio_mac_address is not None:
            self.radio_mac_address = radio_mac_address
        if last_status_update is not None:
            self.last_status_update = last_status_update
        self.active = active
        if software_version is not None:
            self.software_version = software_version
        self.online_node_count = online_node_count
        if location is not None:
            self.location = location
        if corporation is not None:
            self.corporation = corporation
        if base_station is not None:
            self.base_station = base_station
        if is_online is not None:
            self.is_online = is_online

    @property
    def id(self):
        """Gets the id of this RepeaterResponse.  # noqa: E501


        :return: The id of this RepeaterResponse.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this RepeaterResponse.


        :param id: The id of this RepeaterResponse.  # noqa: E501
        :type: int
        """
        if id is None:
            raise ValueError("Invalid value for `id`, must not be `None`")  # noqa: E501

        self._id = id

    @property
    def name(self):
        """Gets the name of this RepeaterResponse.  # noqa: E501


        :return: The name of this RepeaterResponse.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this RepeaterResponse.


        :param name: The name of this RepeaterResponse.  # noqa: E501
        :type: str
        """

        self._name = name

    @property
    def serial_number(self):
        """Gets the serial_number of this RepeaterResponse.  # noqa: E501


        :return: The serial_number of this RepeaterResponse.  # noqa: E501
        :rtype: str
        """
        return self._serial_number

    @serial_number.setter
    def serial_number(self, serial_number):
        """Sets the serial_number of this RepeaterResponse.


        :param serial_number: The serial_number of this RepeaterResponse.  # noqa: E501
        :type: str
        """
        if serial_number is None:
            raise ValueError("Invalid value for `serial_number`, must not be `None`")  # noqa: E501

        self._serial_number = serial_number

    @property
    def radio_mac_address(self):
        """Gets the radio_mac_address of this RepeaterResponse.  # noqa: E501


        :return: The radio_mac_address of this RepeaterResponse.  # noqa: E501
        :rtype: str
        """
        return self._radio_mac_address

    @radio_mac_address.setter
    def radio_mac_address(self, radio_mac_address):
        """Sets the radio_mac_address of this RepeaterResponse.


        :param radio_mac_address: The radio_mac_address of this RepeaterResponse.  # noqa: E501
        :type: str
        """

        self._radio_mac_address = radio_mac_address

    @property
    def last_status_update(self):
        """Gets the last_status_update of this RepeaterResponse.  # noqa: E501


        :return: The last_status_update of this RepeaterResponse.  # noqa: E501
        :rtype: datetime
        """
        return self._last_status_update

    @last_status_update.setter
    def last_status_update(self, last_status_update):
        """Sets the last_status_update of this RepeaterResponse.


        :param last_status_update: The last_status_update of this RepeaterResponse.  # noqa: E501
        :type: datetime
        """

        self._last_status_update = last_status_update

    @property
    def active(self):
        """Gets the active of this RepeaterResponse.  # noqa: E501


        :return: The active of this RepeaterResponse.  # noqa: E501
        :rtype: bool
        """
        return self._active

    @active.setter
    def active(self, active):
        """Sets the active of this RepeaterResponse.


        :param active: The active of this RepeaterResponse.  # noqa: E501
        :type: bool
        """
        if active is None:
            raise ValueError("Invalid value for `active`, must not be `None`")  # noqa: E501

        self._active = active

    @property
    def software_version(self):
        """Gets the software_version of this RepeaterResponse.  # noqa: E501


        :return: The software_version of this RepeaterResponse.  # noqa: E501
        :rtype: str
        """
        return self._software_version

    @software_version.setter
    def software_version(self, software_version):
        """Sets the software_version of this RepeaterResponse.


        :param software_version: The software_version of this RepeaterResponse.  # noqa: E501
        :type: str
        """

        self._software_version = software_version

    @property
    def online_node_count(self):
        """Gets the online_node_count of this RepeaterResponse.  # noqa: E501


        :return: The online_node_count of this RepeaterResponse.  # noqa: E501
        :rtype: int
        """
        return self._online_node_count

    @online_node_count.setter
    def online_node_count(self, online_node_count):
        """Sets the online_node_count of this RepeaterResponse.


        :param online_node_count: The online_node_count of this RepeaterResponse.  # noqa: E501
        :type: int
        """
        if online_node_count is None:
            raise ValueError("Invalid value for `online_node_count`, must not be `None`")  # noqa: E501

        self._online_node_count = online_node_count

    @property
    def location(self):
        """Gets the location of this RepeaterResponse.  # noqa: E501


        :return: The location of this RepeaterResponse.  # noqa: E501
        :rtype: LocationChild
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this RepeaterResponse.


        :param location: The location of this RepeaterResponse.  # noqa: E501
        :type: LocationChild
        """

        self._location = location

    @property
    def corporation(self):
        """Gets the corporation of this RepeaterResponse.  # noqa: E501


        :return: The corporation of this RepeaterResponse.  # noqa: E501
        :rtype: CorporationChild
        """
        return self._corporation

    @corporation.setter
    def corporation(self, corporation):
        """Sets the corporation of this RepeaterResponse.


        :param corporation: The corporation of this RepeaterResponse.  # noqa: E501
        :type: CorporationChild
        """

        self._corporation = corporation

    @property
    def base_station(self):
        """Gets the base_station of this RepeaterResponse.  # noqa: E501


        :return: The base_station of this RepeaterResponse.  # noqa: E501
        :rtype: BaseStationChild
        """
        return self._base_station

    @base_station.setter
    def base_station(self, base_station):
        """Sets the base_station of this RepeaterResponse.


        :param base_station: The base_station of this RepeaterResponse.  # noqa: E501
        :type: BaseStationChild
        """

        self._base_station = base_station

    @property
    def is_online(self):
        """Gets the is_online of this RepeaterResponse.  # noqa: E501


        :return: The is_online of this RepeaterResponse.  # noqa: E501
        :rtype: bool
        """
        return self._is_online

    @is_online.setter
    def is_online(self, is_online):
        """Sets the is_online of this RepeaterResponse.


        :param is_online: The is_online of this RepeaterResponse.  # noqa: E501
        :type: bool
        """

        self._is_online = is_online

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(RepeaterResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, RepeaterResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class StatisticsReportRequest(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'include_percent_time_in_alarm': 'bool',
        'include_percent_time_in_warning': 'bool',
        'include_percent_on_time': 'bool',
        'include_seconds_in_alarm': 'bool',
        'include_average_value': 'bool',
        'include_max_value': 'bool',
        'filter_id': 'str',
        'start_date': 'datetime',
        'end_date': 'datetime',
        'file_name': 'str'
    }

    attribute_map = {
        'include_percent_time_in_alarm': 'IncludePercentTimeInAlarm',
        'include_percent_time_in_warning': 'IncludePercentTimeInWarning',
        'include_percent_on_time': 'IncludePercentOnTime',
        'include_seconds_in_alarm': 'IncludeSecondsInAlarm',
        'include_average_value': 'IncludeAverageValue',
        'include_max_value': 'IncludeMaxValue',
        'filter_id': 'FilterId',
        'start_date': 'StartDate',
        'end_date': 'EndDate',
        'file_name': 'FileName'
    }

    def __init__(self, include_percent_time_in_alarm=None, include_percent_time_in_warning=None, include_percent_on_time=None, include_seconds_in_alarm=None, include_average_value=None, include_max_value=None, filter_id=None, start_date=None, end_date=None, file_name=None):  # noqa: E501
        """StatisticsReportRequest - a model defined in Swagger"""  # noqa: E501
        self._include_percent_time_in_alarm = None
        self._include_percent_time_in_warning = None
        self._include_percent_on_time = None
        self._include_seconds_in_alarm = None
        self._include_average_value = None
        self._include_max_value = None
        self._filter_id = None
        self._start_date = None
        self._end_date = None
        self._file_name = None
        self.discriminator = None
        if include_percent_time_in_alarm is not None:
            self.include_percent_time_in_alarm = include_percent_time_in_alarm
        if include_percent_time_in_warning is not None:
            self.include_percent_time_in_warning = include_percent_time_in_warning
        if include_percent_on_time is not None:
            self.include_percent_on_time = include_percent_on_time
        if include_seconds_in_alarm is not None:
            self.include_seconds_in_alarm = include_seconds_in_alarm
        if include_average_value is not None:
            self.include_average_value = include_average_value
        if include_max_value is not None:
            self.include_max_value = include_max_value
        if filter_id is not None:
            self.filter_id = filter_id
        self.start_date = start_date
        self.end_date = end_date
        self.file_name = file_name

    @property
    def include_percent_time_in_alarm(self):
        """Gets the include_percent_time_in_alarm of this StatisticsReportRequest.  # noqa: E501

        Whether or not to include percent time in alarm in the calculations  # noqa: E501

        :return: The include_percent_time_in_alarm of this StatisticsReportRequest.  # noqa: E501
        :rtype: bool
        """
        return self._include_percent_time_in_alarm

    @include_percent_time_in_alarm.setter
    def include_percent_time_in_alarm(self, include_percent_time_in_alarm):
        """Sets the include_percent_time_in_alarm of this StatisticsReportRequest.

        Whether or not to include percent time in alarm in the calculations  # noqa: E501

        :param include_percent_time_in_alarm: The include_percent_time_in_alarm of this StatisticsReportRequest.  # noqa: E501
        :type: bool
        """

        self._include_percent_time_in_alarm = include_percent_time_in_alarm

    @property
    def include_percent_time_in_warning(self):
        """Gets the include_percent_time_in_warning of this StatisticsReportRequest.  # noqa: E501

        Whether or not to include percent time in warning in the calculations  # noqa: E501

        :return: The include_percent_time_in_warning of this StatisticsReportRequest.  # noqa: E501
        :rtype: bool
        """
        return self._include_percent_time_in_warning

    @include_percent_time_in_warning.setter
    def include_percent_time_in_warning(self, include_percent_time_in_warning):
        """Sets the include_percent_time_in_warning of this StatisticsReportRequest.

        Whether or not to include percent time in warning in the calculations  # noqa: E501

        :param include_percent_time_in_warning: The include_percent_time_in_warning of this StatisticsReportRequest.  # noqa: E501
        :type: bool
        """

        self._include_percent_time_in_warning = include_percent_time_in_warning

    @property
    def include_percent_on_time(self):
        """Gets the include_percent_on_time of this StatisticsReportRequest.  # noqa: E501

        Whether or not to include percent on time in the calculations  # noqa: E501

        :return: The include_percent_on_time of this StatisticsReportRequest.  # noqa: E501
        :rtype: bool
        """
        return self._include_percent_on_time

    @include_percent_on_time.setter
    def include_percent_on_time(self, include_percent_on_time):
        """Sets the include_percent_on_time of this StatisticsReportRequest.

        Whether or not to include percent on time in the calculations  # noqa: E501

        :param include_percent_on_time: The include_percent_on_time of this StatisticsReportRequest.  # noqa: E501
        :type: bool
        """

        self._include_percent_on_time = include_percent_on_time

    @property
    def include_seconds_in_alarm(self):
        """Gets the include_seconds_in_alarm of this StatisticsReportRequest.  # noqa: E501

        Whether or not to include time in alarm in the calculations  # noqa: E501

        :return: The include_seconds_in_alarm of this StatisticsReportRequest.  # noqa: E501
        :rtype: bool
        """
        return self._include_seconds_in_alarm

    @include_seconds_in_alarm.setter
    def include_seconds_in_alarm(self, include_seconds_in_alarm):
        """Sets the include_seconds_in_alarm of this StatisticsReportRequest.

        Whether or not to include time in alarm in the calculations  # noqa: E501

        :param include_seconds_in_alarm: The include_seconds_in_alarm of this StatisticsReportRequest.  # noqa: E501
        :type: bool
        """

        self._include_seconds_in_alarm = include_seconds_in_alarm

    @property
    def include_average_value(self):
        """Gets the include_average_value of this StatisticsReportRequest.  # noqa: E501

        Whether or not to include the average value in the calculations  # noqa: E501

        :return: The include_average_value of this StatisticsReportRequest.  # noqa: E501
        :rtype: bool
        """
        return self._include_average_value

    @include_average_value.setter
    def include_average_value(self, include_average_value):
        """Sets the include_average_value of this StatisticsReportRequest.

        Whether or not to include the average value in the calculations  # noqa: E501

        :param include_average_value: The include_average_value of this StatisticsReportRequest.  # noqa: E501
        :type: bool
        """

        self._include_average_value = include_average_value

    @property
    def include_max_value(self):
        """Gets the include_max_value of this StatisticsReportRequest.  # noqa: E501

        Whether or not to include the max value in the calculations  # noqa: E501

        :return: The include_max_value of this StatisticsReportRequest.  # noqa: E501
        :rtype: bool
        """
        return self._include_max_value

    @include_max_value.setter
    def include_max_value(self, include_max_value):
        """Sets the include_max_value of this StatisticsReportRequest.

        Whether or not to include the max value in the calculations  # noqa: E501

        :param include_max_value: The include_max_value of this StatisticsReportRequest.  # noqa: E501
        :type: bool
        """

        self._include_max_value = include_max_value

    @property
    def filter_id(self):
        """Gets the filter_id of this StatisticsReportRequest.  # noqa: E501

        The filter to use. Optional  # noqa: E501

        :return: The filter_id of this StatisticsReportRequest.  # noqa: E501
        :rtype: str
        """
        return self._filter_id

    @filter_id.setter
    def filter_id(self, filter_id):
        """Sets the filter_id of this StatisticsReportRequest.

        The filter to use. Optional  # noqa: E501

        :param filter_id: The filter_id of this StatisticsReportRequest.  # noqa: E501
        :type: str
        """

        self._filter_id = filter_id

    @property
    def start_date(self):
        """Gets the start_date of this StatisticsReportRequest.  # noqa: E501

        The start date of the time range to get the report for. Nullable so Required can catch nulls, will not  be null later.  # noqa: E501

        :return: The start_date of this StatisticsReportRequest.  # noqa: E501
        :rtype: datetime
        """
        return self._start_date

    @start_date.setter
    def start_date(self, start_date):
        """Sets the start_date of this StatisticsReportRequest.

        The start date of the time range to get the report for. Nullable so Required can catch nulls, will not  be null later.  # noqa: E501

        :param start_date: The start_date of this StatisticsReportRequest.  # noqa: E501
        :type: datetime
        """
        if start_date is None:
            raise ValueError("Invalid value for `start_date`, must not be `None`")  # noqa: E501

        self._start_date = start_date

    @property
    def end_date(self):
        """Gets the end_date of this StatisticsReportRequest.  # noqa: E501

        The end date of the time range to get the values for. Nullable so Required can catch nulls, will not  be null later.  # noqa: E501

        :return: The end_date of this StatisticsReportRequest.  # noqa: E501
        :rtype: datetime
        """
        return self._end_date

    @end_date.setter
    def end_date(self, end_date):
        """Sets the end_date of this StatisticsReportRequest.

        The end date of the time range to get the values for. Nullable so Required can catch nulls, will not  be null later.  # noqa: E501

        :param end_date: The end_date of this StatisticsReportRequest.  # noqa: E501
        :type: datetime
        """
        if end_date is None:
            raise ValueError("Invalid value for `end_date`, must not be `None`")  # noqa: E501

        self._end_date = end_date

    @property
    def file_name(self):
        """Gets the file_name of this StatisticsReportRequest.  # noqa: E501

        The filename to use for the report  # noqa: E501

        :return: The file_name of this StatisticsReportRequest.  # noqa: E501
        :rtype: str
        """
        return self._file_name

    @file_name.setter
    def file_name(self, file_name):
        """Sets the file_name of this StatisticsReportRequest.

        The filename to use for the report  # noqa: E501

        :param file_name: The file_name of this StatisticsReportRequest.  # noqa: E501
        :type: str
        """
        if file_name is None:
            raise ValueError("Invalid value for `file_name`, must not be `None`")  # noqa: E501

        self._file_name = file_name

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(StatisticsReportRequest, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, StatisticsReportRequest):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class InstallNodeResponse(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'node_id': 'int',
        'install_id': 'str',
        'node_serial_number': 'str',
        'node_nickname': 'str',
        'install_status': 'InstallNodeStatusChild',
        'location': 'LocationChild'
    }

    attribute_map = {
        'node_id': 'NodeId',
        'install_id': 'InstallId',
        'node_serial_number': 'NodeSerialNumber',
        'node_nickname': 'NodeNickname',
        'install_status': 'InstallStatus',
        'location': 'Location'
    }

    def __init__(self, node_id=None, install_id=None, node_serial_number=None, node_nickname=None, install_status=None, location=None):  # noqa: E501
        """InstallNodeResponse - a model defined in Swagger"""  # noqa: E501
        self._node_id = None
        self._install_id = None
        self._node_serial_number = None
        self._node_nickname = None
        self._install_status = None
        self._location = None
        self.discriminator = None
        self.node_id = node_id
        if install_id is not None:
            self.install_id = install_id
        self.node_serial_number = node_serial_number
        if node_nickname is not None:
            self.node_nickname = node_nickname
        if install_status is not None:
            self.install_status = install_status
        if location is not None:
            self.location = location

    @property
    def node_id(self):
        """Gets the node_id of this InstallNodeResponse.  # noqa: E501


        :return: The node_id of this InstallNodeResponse.  # noqa: E501
        :rtype: int
        """
        return self._node_id

    @node_id.setter
    def node_id(self, node_id):
        """Sets the node_id of this InstallNodeResponse.


        :param node_id: The node_id of this InstallNodeResponse.  # noqa: E501
        :type: int
        """
        if node_id is None:
            raise ValueError("Invalid value for `node_id`, must not be `None`")  # noqa: E501

        self._node_id = node_id

    @property
    def install_id(self):
        """Gets the install_id of this InstallNodeResponse.  # noqa: E501


        :return: The install_id of this InstallNodeResponse.  # noqa: E501
        :rtype: str
        """
        return self._install_id

    @install_id.setter
    def install_id(self, install_id):
        """Sets the install_id of this InstallNodeResponse.


        :param install_id: The install_id of this InstallNodeResponse.  # noqa: E501
        :type: str
        """

        self._install_id = install_id

    @property
    def node_serial_number(self):
        """Gets the node_serial_number of this InstallNodeResponse.  # noqa: E501


        :return: The node_serial_number of this InstallNodeResponse.  # noqa: E501
        :rtype: str
        """
        return self._node_serial_number

    @node_serial_number.setter
    def node_serial_number(self, node_serial_number):
        """Sets the node_serial_number of this InstallNodeResponse.


        :param node_serial_number: The node_serial_number of this InstallNodeResponse.  # noqa: E501
        :type: str
        """
        if node_serial_number is None:
            raise ValueError("Invalid value for `node_serial_number`, must not be `None`")  # noqa: E501

        self._node_serial_number = node_serial_number

    @property
    def node_nickname(self):
        """Gets the node_nickname of this InstallNodeResponse.  # noqa: E501


        :return: The node_nickname of this InstallNodeResponse.  # noqa: E501
        :rtype: str
        """
        return self._node_nickname

    @node_nickname.setter
    def node_nickname(self, node_nickname):
        """Sets the node_nickname of this InstallNodeResponse.


        :param node_nickname: The node_nickname of this InstallNodeResponse.  # noqa: E501
        :type: str
        """

        self._node_nickname = node_nickname

    @property
    def install_status(self):
        """Gets the install_status of this InstallNodeResponse.  # noqa: E501


        :return: The install_status of this InstallNodeResponse.  # noqa: E501
        :rtype: InstallNodeStatusChild
        """
        return self._install_status

    @install_status.setter
    def install_status(self, install_status):
        """Sets the install_status of this InstallNodeResponse.


        :param install_status: The install_status of this InstallNodeResponse.  # noqa: E501
        :type: InstallNodeStatusChild
        """

        self._install_status = install_status

    @property
    def location(self):
        """Gets the location of this InstallNodeResponse.  # noqa: E501


        :return: The location of this InstallNodeResponse.  # noqa: E501
        :rtype: LocationChild
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this InstallNodeResponse.


        :param location: The location of this InstallNodeResponse.  # noqa: E501
        :type: LocationChild
        """

        self._location = location

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(InstallNodeResponse, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, InstallNodeResponse):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class ActivityEventAssignmentChild(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'assignment_id': 'str',
        'assignment_type': 'ActivityEventAssignmentType',
        'assignment_date_time': 'datetime',
        'assignment_note': 'str',
        'assignment_user': 'UserChild'
    }

    attribute_map = {
        'assignment_id': 'AssignmentId',
        'assignment_type': 'AssignmentType',
        'assignment_date_time': 'AssignmentDateTime',
        'assignment_note': 'AssignmentNote',
        'assignment_user': 'AssignmentUser'
    }

    def __init__(self, assignment_id=None, assignment_type=None, assignment_date_time=None, assignment_note=None, assignment_user=None):  # noqa: E501
        """ActivityEventAssignmentChild - a model defined in Swagger"""  # noqa: E501
        self._assignment_id = None
        self._assignment_type = None
        self._assignment_date_time = None
        self._assignment_note = None
        self._assignment_user = None
        self.discriminator = None
        self.assignment_id = assignment_id
        self.assignment_type = assignment_type
        self.assignment_date_time = assignment_date_time
        if assignment_note is not None:
            self.assignment_note = assignment_note
        if assignment_user is not None:
            self.assignment_user = assignment_user

    @property
    def assignment_id(self):
        """Gets the assignment_id of this ActivityEventAssignmentChild.  # noqa: E501

        Assignment record id  # noqa: E501

        :return: The assignment_id of this ActivityEventAssignmentChild.  # noqa: E501
        :rtype: str
        """
        return self._assignment_id

    @assignment_id.setter
    def assignment_id(self, assignment_id):
        """Sets the assignment_id of this ActivityEventAssignmentChild.

        Assignment record id  # noqa: E501

        :param assignment_id: The assignment_id of this ActivityEventAssignmentChild.  # noqa: E501
        :type: str
        """
        if assignment_id is None:
            raise ValueError("Invalid value for `assignment_id`, must not be `None`")  # noqa: E501

        self._assignment_id = assignment_id

    @property
    def assignment_type(self):
        """Gets the assignment_type of this ActivityEventAssignmentChild.  # noqa: E501


        :return: The assignment_type of this ActivityEventAssignmentChild.  # noqa: E501
        :rtype: ActivityEventAssignmentType
        """
        return self._assignment_type

    @assignment_type.setter
    def assignment_type(self, assignment_type):
        """Sets the assignment_type of this ActivityEventAssignmentChild.


        :param assignment_type: The assignment_type of this ActivityEventAssignmentChild.  # noqa: E501
        :type: ActivityEventAssignmentType
        """
        if assignment_type is None:
            raise ValueError("Invalid value for `assignment_type`, must not be `None`")  # noqa: E501

        self._assignment_type = assignment_type

    @property
    def assignment_date_time(self):
        """Gets the assignment_date_time of this ActivityEventAssignmentChild.  # noqa: E501

        Date of assignment  # noqa: E501

        :return: The assignment_date_time of this ActivityEventAssignmentChild.  # noqa: E501
        :rtype: datetime
        """
        return self._assignment_date_time

    @assignment_date_time.setter
    def assignment_date_time(self, assignment_date_time):
        """Sets the assignment_date_time of this ActivityEventAssignmentChild.

        Date of assignment  # noqa: E501

        :param assignment_date_time: The assignment_date_time of this ActivityEventAssignmentChild.  # noqa: E501
        :type: datetime
        """
        if assignment_date_time is None:
            raise ValueError("Invalid value for `assignment_date_time`, must not be `None`")  # noqa: E501

        self._assignment_date_time = assignment_date_time

    @property
    def assignment_note(self):
        """Gets the assignment_note of this ActivityEventAssignmentChild.  # noqa: E501

        Note (if available) for this assignment  # noqa: E501

        :return: The assignment_note of this ActivityEventAssignmentChild.  # noqa: E501
        :rtype: str
        """
        return self._assignment_note

    @assignment_note.setter
    def assignment_note(self, assignment_note):
        """Sets the assignment_note of this ActivityEventAssignmentChild.

        Note (if available) for this assignment  # noqa: E501

        :param assignment_note: The assignment_note of this ActivityEventAssignmentChild.  # noqa: E501
        :type: str
        """

        self._assignment_note = assignment_note

    @property
    def assignment_user(self):
        """Gets the assignment_user of this ActivityEventAssignmentChild.  # noqa: E501


        :return: The assignment_user of this ActivityEventAssignmentChild.  # noqa: E501
        :rtype: UserChild
        """
        return self._assignment_user

    @assignment_user.setter
    def assignment_user(self, assignment_user):
        """Sets the assignment_user of this ActivityEventAssignmentChild.


        :param assignment_user: The assignment_user of this ActivityEventAssignmentChild.  # noqa: E501
        :type: UserChild
        """

        self._assignment_user = assignment_user

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(ActivityEventAssignmentChild, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ActivityEventAssignmentChild):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import pprint
import re  # noqa: F401

import six

class HierarchyChild(object):
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """
    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'hierarchy_id': 'str',
        'hierarchy_name': 'str',
        'hierarchy_abbreviation': 'str',
        'hierarchy_type': 'str'
    }

    attribute_map = {
        'hierarchy_id': 'HierarchyId',
        'hierarchy_name': 'HierarchyName',
        'hierarchy_abbreviation': 'HierarchyAbbreviation',
        'hierarchy_type': 'HierarchyType'
    }

    def __init__(self, hierarchy_id=None, hierarchy_name=None, hierarchy_abbreviation=None, hierarchy_type=None):  # noqa: E501
        """HierarchyChild - a model defined in Swagger"""  # noqa: E501
        self._hierarchy_id = None
        self._hierarchy_name = None
        self._hierarchy_abbreviation = None
        self._hierarchy_type = None
        self.discriminator = None
        self.hierarchy_id = hierarchy_id
        self.hierarchy_name = hierarchy_name
        if hierarchy_abbreviation is not None:
            self.hierarchy_abbreviation = hierarchy_abbreviation
        self.hierarchy_type = hierarchy_type

    @property
    def hierarchy_id(self):
        """Gets the hierarchy_id of this HierarchyChild.  # noqa: E501


        :return: The hierarchy_id of this HierarchyChild.  # noqa: E501
        :rtype: str
        """
        return self._hierarchy_id

    @hierarchy_id.setter
    def hierarchy_id(self, hierarchy_id):
        """Sets the hierarchy_id of this HierarchyChild.


        :param hierarchy_id: The hierarchy_id of this HierarchyChild.  # noqa: E501
        :type: str
        """
        if hierarchy_id is None:
            raise ValueError("Invalid value for `hierarchy_id`, must not be `None`")  # noqa: E501

        self._hierarchy_id = hierarchy_id

    @property
    def hierarchy_name(self):
        """Gets the hierarchy_name of this HierarchyChild.  # noqa: E501


        :return: The hierarchy_name of this HierarchyChild.  # noqa: E501
        :rtype: str
        """
        return self._hierarchy_name

    @hierarchy_name.setter
    def hierarchy_name(self, hierarchy_name):
        """Sets the hierarchy_name of this HierarchyChild.


        :param hierarchy_name: The hierarchy_name of this HierarchyChild.  # noqa: E501
        :type: str
        """
        if hierarchy_name is None:
            raise ValueError("Invalid value for `hierarchy_name`, must not be `None`")  # noqa: E501

        self._hierarchy_name = hierarchy_name

    @property
    def hierarchy_abbreviation(self):
        """Gets the hierarchy_abbreviation of this HierarchyChild.  # noqa: E501


        :return: The hierarchy_abbreviation of this HierarchyChild.  # noqa: E501
        :rtype: str
        """
        return self._hierarchy_abbreviation

    @hierarchy_abbreviation.setter
    def hierarchy_abbreviation(self, hierarchy_abbreviation):
        """Sets the hierarchy_abbreviation of this HierarchyChild.


        :param hierarchy_abbreviation: The hierarchy_abbreviation of this HierarchyChild.  # noqa: E501
        :type: str
        """

        self._hierarchy_abbreviation = hierarchy_abbreviation

    @property
    def hierarchy_type(self):
        """Gets the hierarchy_type of this HierarchyChild.  # noqa: E501


        :return: The hierarchy_type of this HierarchyChild.  # noqa: E501
        :rtype: str
        """
        return self._hierarchy_type

    @hierarchy_type.setter
    def hierarchy_type(self, hierarchy_type):
        """Sets the hierarchy_type of this HierarchyChild.


        :param hierarchy_type: The hierarchy_type of this HierarchyChild.  # noqa: E501
        :type: str
        """
        if hierarchy_type is None:
            raise ValueError("Invalid value for `hierarchy_type`, must not be `None`")  # noqa: E501

        self._hierarchy_type = hierarchy_type

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in six.iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value
        if issubclass(HierarchyChild, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, HierarchyChild):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        return not self == other



# coding: utf-8

"""
    Internal API

    SmartDiagnostics REST API for internal users only  # noqa: E501

    OpenAPI spec version: v3
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

from __future__ import absolute_import

import unittest

import smart_diagnostics_client
from smart_diagnostics_client.api.hubs_api import HubsApi  # noqa: E501
from smart_diagnostics_client.rest import ApiException


class TestHubsApi(unittest.TestCase):
    """HubsApi unit test stubs"""

    def setUp(self):
        self.api = HubsApi()  # noqa: E501

    def tearDown(self):
        pass

    def test_export_hub_overview(self):
        """Test case for export_hub_overview

        Exports hub information  # noqa: E501
        """
        pass

    def test_get_hub(self):
        """Test case for get_hub

        Returns a single Hub with the supplied Id  # noqa: E501
        """
        pass

    def test_get_hubs(self):
        """Test case for get_hubs

        Gets all hubs a user has access to  # noqa: E501
        """
        pass


if __name__ == '__main__':
    unittest.main()
